# NStudyPy 
NStudyPy 工具包


## 使用方法
```bash
pip install -U NStudyPy -i https://pypi.org/simple
```

## 版本更新历史

## version 0.0.13
- 更新 `PyFile`

## version 0.0.12
- 更新 `PyDate` `PyFile`

## version 0.0.11
- 更新 `PyWeb`
- 添加/更新 `PyLabelStudio`

## version 0.0.10
- 更新 `PyWeb`
- 添加/更新 `PyLabelStudio`
- 更新 `PyString`

## version 0.0.9
- 添加/更新 `PyWeb`
- 添加 `PyLabelStudio`

## version 0.0.8
- 添加/更新 `PyFile`
- 添加 `PyEnv`
- 删除 `PyTools.get_env`

## version 0.0.7
- fix bug

## version 0.0.6
- 添加 `PyWeb` `PyFile` 工具
- 更新 `PyString` `PyTools` 工具

## version 0.0.5
- 添加 `PyDate` `PyPDF` 工具
- 更新 `PyString` `PyTools` 工具

## version 0.0.4
- Python 升级到 3.9+
- 添加 `PyShape` `PyString` 工具

## version 0.0.3
- 更改包名

## version 0.0.2
- 添加一些方法 `from NStudyPy import PyTools`

## version 0.0.1
- 初始化项目